Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(178)

Unified Diff: src/flag-definitions.h

Issue 148223002: Remove CallICs (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Update test262 status file Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/disassembler.cc ('k') | src/frames.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/flag-definitions.h
diff --git a/src/flag-definitions.h b/src/flag-definitions.h
index e0089e659049d3c78b63aef3437bff5a7ee104fb..c846c4121bc468a0a864e40c2b561dd83180c63d 100644
--- a/src/flag-definitions.h
+++ b/src/flag-definitions.h
@@ -351,8 +351,8 @@ DEFINE_bool(omit_map_checks_for_leaf_maps, true,
// Profiler flags.
DEFINE_int(frame_count, 1, "number of stack frames inspected by the profiler")
- // 0x1700 fits in the immediate field of an ARM instruction.
-DEFINE_int(interrupt_budget, 0x1700,
+ // 0x1800 fits in the immediate field of an ARM instruction.
+DEFINE_int(interrupt_budget, 0x1800,
"execution budget before interrupt is triggered")
DEFINE_int(type_info_threshold, 25,
"percentage of ICs that must have type info to allow optimization")
« no previous file with comments | « src/disassembler.cc ('k') | src/frames.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698